package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.auth.fegin.UserFeignService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.pojo.DTO.UserDto;
import com.bwie.common.pojo.User;
import com.bwie.common.pojo.vo.UserVo;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Random;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @author 86175
 * 登录的业务层
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeignService userFeignService;
    @Autowired
    private StringRedisTemplate redisTemplate;



    @Override
    public Result sendCode(String userPhone) {

        //feign调用查出sql数据
        Result<User> userResult = userFeignService.sendCode(userPhone);
        User user = userResult.getData();
        if (user==null){
            return Result.success("手机号不能为空");
        }
        String code="";
        for (int i = 0; i < 4; i++) {
            code+=new Random().nextInt(10);
        }
        redisTemplate.opsForValue().set(userPhone,code,15, TimeUnit.MINUTES);
        return Result.success(code,"发送成功");
    }

    @Override
    public Result users(UserVo userVo) {

        //feign调用查出sql数据
        Result<User> userName = userFeignService.sendCode(userVo.getUserPhone());
        User user = userName.getData();
        if (user==null){
            return Result.error("该用户不存在，请先注册");
        }

        if (!userVo.getUserPhone().equals(user.getUserPhone())){
            return Result.error("手机号不正确");
        }
        if (!redisTemplate.hasKey(userVo.getUserPhone())){
            return Result.error("验证码已过期");
        }
        String code = redisTemplate.opsForValue().get(userVo.getUserPhone());
        if (!code.equals(userVo.getCode())){
            return Result.error("验证码失败");
        }

        HashMap<String, Object> map = new HashMap<>();
        String userKey = UUID.randomUUID().toString();
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSON.toJSONString(user),30,TimeUnit.MINUTES);
        UserDto userDto = new UserDto();
        userDto.setToken(token);
        userDto.setExpiredTime("token存储时间是30分钟");
        if (user.getUserRole()==1){
            return Result.success(userDto,"管理员登录");
        }
        return Result.success(userDto,"欢迎登录");
    }

    @Override
    public Result register(UserVo userVo) {

         userFeignService.register(userVo);

        return Result.success("注册成功");
    }


}
