package com.bwie.user.controller;

import com.alibaba.fastjson.JSON;
import com.bwie.common.pojo.User;
import com.bwie.common.pojo.vo.UserVo;
import com.bwie.common.result.Result;
import com.bwie.user.service.UserService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;

/**
 * @author 86175
 */
@RestController
@Log4j2
@RequestMapping("/user")
public class UserController {

    @Autowired
    private HttpServletRequest request;
    @Autowired
    private UserService userService;
    /**
     * 发送验证码的时候查看是否存在手机号
     */
    @PostMapping("/sendCode/{userPhone}")
    public Result<User> sendCode(@PathVariable String userPhone){

        log.info("功能描述：查询后台是否存在这个手机号,请求URI:{},请求方式:{},请求参数:{}",request.getServletPath(),request.getMethod(),userPhone);

        User user=userService.sendCode(userPhone);
        Result result =Result.success(user);
        log.info("功能描述：查询后台是否存在这个手机号,请求URI:{},请求方式:{},响应结果:{}",request.getServletPath(),request.getMethod(), JSON.toJSONString(result));
        return result;
    }


    @PostMapping("/findUserName/{userName}")
    public Result<User> findUserName(@PathVariable String userName){

        log.info("功能描述：查询后台是否存在这个用户名,请求URI:{},请求方式:{},请求参数:{}",request.getServletPath(),request.getMethod(),userName);

        User user=userService.findUserName(userName);
        Result result =Result.success(user);
        log.info("功能描述：查询后台是否存在这个用户名,请求URI:{},请求方式:{},响应结果:{}",request.getServletPath(),request.getMethod(), JSON.toJSONString(result));
        return result;
    }

    /**
     * 注册
     */
    @PostMapping("/register")
    public Result register(@RequestBody UserVo userVo){

        log.info("功能描述：当用户不存在时，请注册,请求URI:{},请求方式:{},请求参数:{}",request.getServletPath(),request.getMethod(),userVo);
        Result result=userService.register(userVo);
        log.info("功能描述：当用户不存在时，请注册,请求URI:{},请求方式:{},响应结果:{}",request.getServletPath(),request.getMethod(), JSON.toJSONString(result));
        return result;
    }
    /**
     * 上传图片
     */
    @PostMapping("/upload")
    public Result upload(@RequestBody MultipartFile file){
        log.info("功能描述：上传图片,请求URI:{},请求方式:{},请求参数:{}",request.getServletPath(),request.getMethod(),file);
        Result result=userService.upload(file);
        log.info("功能描述：上传图片,请求URI:{},请求方式:{},响应结果:{}",request.getServletPath(),request.getMethod(), JSON.toJSONString(result));
        return result;
    }
}
