package com.bwie.mq.config;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.support.converter.Jackson2JsonMessageConverter;
import org.springframework.amqp.support.converter.MessageConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import javax.annotation.PostConstruct;

@Configuration
public class RabbitMQConfig implements RabbitTemplate.ConfirmCallback,RabbitTemplate.ReturnsCallback {

    public static final String DELQUEUE = "delQueue";
    public static final String delExchange = "delExchange";
    public static final String routingKey = "delKey";

    public static final Logger logger = LoggerFactory.getLogger(RabbitMQConfig.class);

    private RabbitTemplate rabbitTemplate;


    //创建消息转换器
    @Bean
    public MessageConverter messageConverter(){
        return new Jackson2JsonMessageConverter();
    }

    //创建队列
    @Bean
    public Queue queue(){
        return new Queue(DELQUEUE,true);
    }

    //创建交换机 -- 直连
    @Bean("delExchange")
    public DirectExchange directExchange(){
        return new DirectExchange(delExchange);
    }

    @Primary
    @Bean
    public RabbitTemplate rabbitTemplate(ConnectionFactory connectionFactory){
        RabbitTemplate rabbitTemplate = new RabbitTemplate(connectionFactory);
        this.rabbitTemplate = rabbitTemplate;
        rabbitTemplate.setMessageConverter(messageConverter());
        rabbitTemplate();
        return rabbitTemplate;
    }

    public void rabbitTemplate(){

        rabbitTemplate.setConfirmCallback(this);
        rabbitTemplate.setReturnsCallback(this);
    }

    //绑定 -- 队列--交换机---设置路由键
    @Bean
    public Binding binding(){
        return BindingBuilder.bind(queue()).to(directExchange()).with(routingKey);
    }

    @Override
    public void confirm(CorrelationData correlationData, boolean ack, String s) {

        if(ack){
            logger.info("{}消息到达交换机",correlationData.getId());
        }else{
            logger.error("{}消息丢失",correlationData.getId());
        }
    }

    @Override
    public void returnedMessage(ReturnedMessage returnedMessage) {
        logger.error("{}消息未到达队列",returnedMessage.getMessage().getMessageProperties().getMessageId());
    }
}
